# lxd-io

Read [leveLXData](https://levelxdata.com/) datasets without boilerplate code.

* Supported datasets: exiD, highD, inD, rounD, uniD

* Tested on: highD, exiD

## Install

Install with pip

```bash
python -m pip install lxd-io
```

## Use

Check [the tutorial notebook](https://github.com/lenvt/lxd-io/blob/main/tutorial.ipynb) or [test/test_lxd_io.py](https://github.com/lenvt/lxd-io/blob/main/test/test_lxd_io.py) for usage info.
